%define major 8
%define libname %mklibname rrdtool %{major}
%define develname %mklibname -d rrdtool

Summary:	Round Robin Database Tool to store and display time-series data
Name:		rrdtool
Version:	1.6.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Networking/Other
URL:		http://oss.oetiker.ch/rrdtool/
Source0:	http://oss.oetiker.ch/rrdtool/pub/%{name}-%{version}.tar.gz
Source1:	rrdcached.service
Source2:	rrdcached.socket
Source3:	rrdcached.sysconfig
Source4:	rrdcached.tmpfiles
Patch1:		rrdtool-1.2.23-fix-examples.patch
Patch2:		rrdtool-1.4.1-avoid-version.diff
# Install tcl bindings to correct location as per policy (the upstream
# conditional that should nearly do this doesn't work) - AdamW 2008/12
Patch5:		rrdtool-1.4.8-tcl_location.diff
Patch6:		rrdtool-1.6.0-ruby-2-fix.patch
Patch9:		rrdtool-1.5.5-socket_dir.diff
Requires:	fonts-ttf-dejavu
BuildRequires:	cairo-devel
BuildRequires:	chrpath
BuildRequires:	dbi-devel
BuildRequires:	freetype-devel
BuildRequires:	gettext
BuildRequires:	gettext-devel
BuildRequires:	glib2-devel
BuildRequires:	groff
BuildRequires:	intltool >= 0.35.0
BuildRequires:	libart_lgpl-devel
BuildRequires:	libgd-devel
BuildRequires:	lua-devel
BuildRequires:	lua
BuildRequires:	pango-devel
BuildRequires:	perl-devel
BuildRequires:	png-devel >= 1.0.3
BuildRequires:	python-devel
BuildRequires:	tcl 
BuildRequires:	tcl-devel
BuildRequires:	zlib-devel

%description
RRD is the Acronym for Round Robin Database. RRD is a system to store and
display time-series data (i.e. network bandwidth, machine-room temperature,
server load average). It stores the data in a very compact way that will not
expand over time, and it presents useful graphs by processing the data to
enforce a certain data density. It can be used either via simple wrapper
scripts (from shell or Perl) or via frontends that poll network devices and
put a friendly user interface on it.

%package -n	rrdcached
Summary:	Data caching daemon for RRDtool
Group:		System/Servers
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
Requires:	%{name} >= %{version}-%{release}

%description -n	rrdcached
rrdcached is a daemon that receives updates to existing RRD files, accumulates
them and, if enough have been received or a defined time has passed, writes the
updates to the RRD file. The daemon was written with big setups in mind which
usually runs into I/O related problems. This daemon was written to alleviate
these problems.

%package -n	%{libname}
Summary:	RRDTool - round robin database shared libraries
Group:		System/Libraries

%description -n	%{libname}
RRD is the Acronym for Round Robin Database. RRD is a system to store and
display time-series data (i.e. network bandwidth, machine-room temperature,
server load average). This package allow you to use this library directly.

%package -n	%{develname}
Summary:	Development libraries and headers for %{libname}
Group:		Development/Other
Requires:	%{libname} >= %{version}-%{release}
Requires:	perl-devel
Requires:	libgd-devel
Requires:	zlib-devel
Requires:	freetype-devel
Requires:	libart_lgpl-devel
Provides:	rrdtool-devel = %{version}-%{release}
Provides:	librrdtool-devel = %{version}-%{release}
Obsoletes:	rrdtool-devel
Conflicts:	%{mklibname rrdtool 0 -d}
Conflicts:	%{mklibname rrdtool 2 -d}

%description -n	%{develname}
RRD is the Acronym for Round Robin Database. RRD is a system to store and
display time-series data (i.e. network bandwidth, machine-room temperature,
server load average).

This package provides development libraries and headers for %{libname}.

%package -n	perl-%{name}
Summary:	RRD Tool Perl interface
Group:		Development/Perl
Requires:	%{name} >= %{version}-%{release}

%description -n	perl-%{name}
The RRD Tools Perl modules.

%package -n	python-%{name}
Summary:	RRD Tool Python interface
Group:		Development/Python
Requires:	%{name} >= %{version}-%{release}
Requires:	python >= 2.3

%description -n	python-%{name}
The RRD Tools Python modules.

%package -n	tcl-%{name}
Summary:	RRD Tool TCL interface
Group:		Development/Other
Requires:	%{name} >= %{version}-%{release}
Requires:	tcl

%description -n	tcl-%{name}
The RRD Tools TCL modules.

%package -n	lua-%{name}
Summary:	RRD Tool LUA interface
Group:		Development/Other
Requires:	%{name} >= %{version}-%{release}
Requires:	lua

%description -n	lua-%{name}
The RRD Tools LUA module.

%prep

%setup -q
%patch1 -p1
%patch2 -p1
%patch5 -p1 -b .tcl_location
%patch6 -p1 -b .ruby-2-fix
%patch9 -p1 -b .socket_dir

%build
autoreconf -fi

%configure2_5x \
    --disable-rpath \
    --disable-static \
    --with-pic \
    --with-perl-options="INSTALLDIRS=vendor" \
    --with-tcllib=%{_libdir} \
    --enable-tcl-site \
    --disable-ruby

make

%install
%makeinstall_std

# equivalent of "make site-perl-install" except for the PREFIX
# "make site-perl-install" is not done by "make install"
%makeinstall_std -C bindings/perl-piped install_vendor
%makeinstall_std -C bindings/perl-shared install_vendor

%{__install} -d %{buildroot}%{_sbindir}

# now create include and files
%{__install} -d %{buildroot}%{_includedir}
%{__install} -m644 src/rrd*.h %{buildroot}%{_includedir}/

# moving the docs in the right place (another approach)
rm -rf installed_docs
mkdir -p installed_docs/{html,pod,txt,examples/rrdcached}
cp doc/*.txt installed_docs/txt/
cp doc/*.pod installed_docs/pod/
cp doc/*.html installed_docs/html/
cp examples/*.{cgi,pl} installed_docs/examples/
cp examples/rrdcached/*.{pm,pl} installed_docs/examples/rrdcached/
# fix attribs
find installed_docs -type f | xargs chmod 644

#removing things installed in the wrong place
%{__rm} -rf %{buildroot}%{_prefix}/lib/perl/*.pm
%{__rm} -rf %{buildroot}%{_prefix}/lib/perl/auto/RRDs/RRDs*
%{__rm} -rf %{buildroot}%{_prefix}/lib/perl5/site_perl
%{__rm} -rf %{buildroot}%{_prefix}/shared
%{__rm} -rf %{buildroot}%{_datadir}/doc/%{name}*

# icky ntmake.pl
%{__rm} -f %{buildroot}%{perl_vendorarch}/ntmake.pl

# I've tried and tried and tried to get rid of the rpath.
# It only appears after you do a make install, so I have
# no idea what is doing it but this gets rid of it...
#chrpath -d %{buildroot}%{_bindir}/*

# the problem has now moved to the perl stuff...
find %{buildroot}%{_prefix}/lib/perl* -name "*.so" | xargs chmod u+w
find %{buildroot}%{_prefix}/lib/perl* -name "*.so" | xargs chrpath -d 

# and the tcl stuff
chrpath -d %{buildroot}%{_libdir}/tclrrd%{version}.so

# remove .in/.am files
find %{buildroot} -name "*.in" | xargs %{__rm} -f
find %{buildroot} -name "*.am" | xargs %{__rm} -f

# remove .la file
rm -f %{buildroot}%{_libdir}/*.la

# install rrdcached files
install -d %{buildroot}/var/lib/rrdcached

install -D -m 755 %{SOURCE1} %{buildroot}%{_unitdir}/rrdcached.service
install -D -m 755 %{SOURCE2} %{buildroot}%{_unitdir}/rrdcached.socket
install -D -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/rrdcached
install -D -m 644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/rrdcached.conf

# cleanup
rm -f %{buildroot}%{_libdir}/lua/*/*.*a
rm -rf %{buildroot}%{_datadir}/rrdtool

%pre -n rrdcached
%_pre_useradd rrdcached /var/lib/rrdcached /sbin/nologin

%post -n rrdcached
%_tmpfilescreate rrdcached
%_post_service rrdcached

%preun -n rrdcached
%_preun_service rrdcached

%postun -n rrdcached
%_postun_userdel rrdcached

%files
%doc CONTRIBUTORS COPYRIGHT NEWS THREADS TODO
%doc installed_docs/txt installed_docs/html
%{_bindir}/rrdcgi
%{_bindir}/rrdcreate
%{_bindir}/rrdinfo
%{_bindir}/rrdtool
%{_bindir}/rrdupdate
%exclude %{_mandir}/man1/rrdcached.1*
%{_mandir}/man1/*

%files -n rrdcached
%{_unitdir}/rrdcached.service
%{_unitdir}/rrdcached.socket
%config(noreplace) %{_sysconfdir}/sysconfig/rrdcached
%{_tmpfilesdir}/rrdcached.conf
%{_bindir}/rrdcached
%attr(0755,rrdcached,rrdcached) %dir /var/lib/rrdcached
%{_mandir}/man1/rrdcached*

%files -n %{libname}
%doc COPYRIGHT
%{_libdir}/librrd.so.%{major}
%{_libdir}/librrd.so.%{major}.*
%{_mandir}/man3/librrd.3*

%files -n %{develname}
%doc COPYRIGHT
%exclude %{_libdir}/tclrrd%{version}.so
%{_libdir}/*.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/librrd.pc

%files -n perl-%{name}
%doc installed_docs/pod installed_docs/examples
%{perl_vendorarch}/*.pm
%{perl_vendorlib}/*.pm
%dir %{perl_vendorarch}/auto/RRDs
%{perl_vendorarch}/auto/RRDs/RRDs.so
%{_mandir}/man3*/RRDp.3*
%{_mandir}/man3*/RRDs.3*

%files -n python-%{name}
%doc bindings/python/AUTHORS bindings/python/COPYING bindings/python/README
%py_platsitedir/*

%files -n tcl-%{name}
%doc bindings/tcl/README
%{_libdir}/tclrrd%{version}.so
%{tcl_sitearch}/tclrrd

%files -n lua-%{name}
%doc bindings/lua/README
%{_libdir}/lua/*/rrd.so


%changelog
* Fri May 06 2016 luigiwalser <luigiwalser> 1.6.0-1.mga6
+ Revision: 1010066
- librrd_th.so library is no more
- library major is now 8
- 1.6.0
- rediff patches 1 and 5
- rediff patch 6 (from fedora)
- remove patches 7 and 8 (fixed upstream)

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Mon Nov 16 2015 oden <oden> 1.5.5-2.mga6
+ Revision: 903536
- stupid bs
- 1.5.5
- rediff patches
- add some fedora patches

* Sat Jun 27 2015 tv <tv> 1.4.8-12.mga6
+ Revision: 846064
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 1.4.8-11.mga6
+ Revision: 840826
- Rebuild for the new perl

* Wed Oct 15 2014 umeabot <umeabot> 1.4.8-10.mga5
+ Revision: 747527
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4.8-9.mga5
+ Revision: 730092
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.8-8.mga5
+ Revision: 688719
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 1.4.8-7.mga5
+ Revision: 632369
- perl 5.20.0 rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.4.8-5.mga4
+ Revision: 544441
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.8-4.mga4
+ Revision: 499833
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Jun 21 2013 guillomovitch <guillomovitch> 1.4.8-3.mga4
+ Revision: 445418
- add fedora patch for imginfo format explict check (CVE-2013-2131, #10559 )

* Sun Jun 02 2013 fwang <fwang> 1.4.8-2.mga4
+ Revision: 434972
- rebuild for new libpng

* Fri May 31 2013 oden <oden> 1.4.8-1.mga4
+ Revision: 433859
- 1.4.8

* Wed May 29 2013 tv <tv> 1.4.7-6.mga4
+ Revision: 430132
- rebuild for new perl

* Sun Mar 24 2013 colin <colin> 1.4.7-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 1.4.7-4.mga3
+ Revision: 380506
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.4.7-3.mga3
+ Revision: 321783
- Use new macros for tmpfilesdir
- Run systemd-tmpfiles --create on post install

  + guillomovitch <guillomovitch>
    - use %%{_prefix}/lib/tmpfiles.d, not %%{_sysconfdir}/tmpfiles.d

* Thu Jul 05 2012 guillomovitch <guillomovitch> 1.4.7-2.mga3
+ Revision: 267928
- fix socket perms handling
- fix temp file configuration

* Thu Jul 05 2012 guillomovitch <guillomovitch> 1.4.7-1.mga3
+ Revision: 267804
- add systemd support
- drop sysinit support
- drop all but explicit patches

* Wed May 30 2012 jquelin <jquelin> 1.4.5-10.mga3
+ Revision: 251639
- perl 5.16 rebuild

* Sat Nov 26 2011 guillomovitch <guillomovitch> 1.4.5-9.mga2
+ Revision: 172341
- drop .la files
- spec cleanup

* Sun Sep 11 2011 fwang <fwang> 1.4.5-8.mga2
+ Revision: 142339
- update tclconfig.sh location
- rebuild for new libpng

* Sun Jun 12 2011 pterjan <pterjan> 1.4.5-7.mga2
+ Revision: 104323
- Rebuild for perl 5.14

* Thu Mar 24 2011 boklm <boklm> 1.4.5-6.mga1
+ Revision: 76205
- rebuild for bug #497

* Mon Mar 07 2011 ennael <ennael> 1.4.5-5.mga1
+ Revision: 65959
- rebuild for bash 4.2 (kindly aske by rtp, grumpf inside)

* Wed Jan 19 2011 jquelin <jquelin> 1.4.5-4.mga1
+ Revision: 23792
- rebuild

* Tue Jan 18 2011 pterjan <pterjan> 1.4.5-3.mga1
+ Revision: 21812
- Rebuild for python 2.7

* Fri Jan 14 2011 dmorgan <dmorgan> 1.4.5-2.mga1
+ Revision: 17449
- Get rid of mdv macros
- imported package rrdtool
- imported package rrdtool

